@@ -1,6 +1,5 @@
 """
-🌱 - xmod: Extend a module with any Python object - 🌱
-=========================================================================
+🌱 Turn any object into a module 🌱
 
 Callable modules!  Indexable modules!?
 
@@ -10,12 +9,10 @@ Ever wanted to call a module directly, or index it?  Or just sick of seeing
 Give your module the awesome power of an object, or maybe just save a
 little typing, with `xmod`.
 
-`xmod` is a tiny library that extends a module to do things that normally
+`xmod` is a tiny library that lets a module to do things that normally
 only a class could do - handy for modules that "just do one thing".
 
-EXAMPLE: Make a module callable as a function
-
-.. code-block:: python
+## Example: Make a module callable like a function!
 
     # In your_module.py
     import xmod
@@ -30,10 +27,7 @@ EXAMPLE: Make a module callable as a function
     >>> your_module()
     HERE!!
 
-
-EXAMPLE: Make a module look like an object
-
-.. code-block:: python
+## Example: Make a module look like a list!?!
 
     # In your_module.py
     import xmod
@@ -49,10 +43,10 @@ EXAMPLE: Make a module look like an object
 """
 __all__ = ('xmod',)
 
+from typing import Any, Optional, Sequence
 import functools
 import sys
 
-__version__ = '1.3.1'
 
 OMIT = {
     '__class__',
@@ -69,8 +63,12 @@ WRAPPED_ATTRIBUTE = '_xmod_wrapped'
 
 
 def xmod(
-    extension=None, name=None, full=None, props=None, omit=None, mutable=False
-):
+    extension: Optional = None,
+    name: Optional[str] = None,
+    full: Optional[bool] = None,
+    omit: Optional[Sequence[str]] = None,
+    mutable: bool = False
+) -> Any:
     """
     Extend the system module at `name` with any Python object.
 
@@ -82,13 +80,11 @@ def xmod(
     `__call__` method is delegated, so `xmod` can also be used as a
     decorator, both with and without parameters.
 
-    ARGUMENTS
-      extension
-        The object whose methods and properties extend the namespace.
+    Args:
+      extension: The object whose methods and properties extend the namespace.
         This includes magic methods like __call__ and __getitem__.
 
-      name
-        The name of this symbol in `sys.modules`.  If this is `None`
+      name: The name of this symbol in `sys.modules`.  If this is `None`
         then `xmod` will use `extension.__module__`.
 
         This only needs to be be set if `extension` is _not_ a function or
@@ -97,29 +93,29 @@ def xmod(
         If the `name` argument is given, it should almost certainly be
         `__name__`.
 
-      full
-        If `False`, just add extension as a callable.
+      full: If `False`, just add extension as a callable.
 
         If `True`, extend the module with all members of `extension`.
 
         If `None`, the default, add the extension if it's a callable, otherwise
         extend the module with all members of `extension`.
 
-      mutable:
-        If `True`, the attributes on the proxy are mutable and write through to
-        the underlying module.  If `False`, the default, attributes on the
-        proxy cannot be changed.
+      mutable: If `True`, the attributes on the proxy are mutable and write
+        through to the underlying module.  If `False`, the default, attributes
+        on the proxy cannot be changed.
 
-      omit
-        A list of methods _not_ to delegate from the proxy to the extension.
+      omit: A list of methods _not_ to delegate from the proxy to the extension.
 
         If `omit` is None, it defaults to `xmod.OMIT`, which seems to
         work well.
+
+    Returns:
+        `extension`, the original item that got decorated
     """
     if extension is None:
         # It's a decorator with properties
         return functools.partial(
-            xmod, name=name, full=full, props=props, omit=omit, mutable=mutable
+            xmod, name=name, full=full, omit=omit, mutable=mutable
         )
 
     def method(f):
@@ -141,11 +137,9 @@ def xmod(
             mutator(lambda v: setattr(extension, k, v)),
             mutator(lambda: delattr(extension, k)),
         )
-    if name is None:
-        if isinstance(extension, functools.partial):
-            name = extension.func.__module__
-        else:
-            name = extension.__module__
+    name = name or getattr(extension, '__module__', None)
+    if not name:
+        raise ValueError('`name` parameter must be set')
 
     module = sys.modules[name]
 
